HRM-deprecated: Deprecated functions in package 'HRM'.

HRM-deprecatedR Documentation

Deprecated functions in package HRM.

Description

The functions listed below are deprecated and will be defunct in the near future. When possible, alternative functions with similar functionality are also mentioned. Help pages for deprecated functions are available at help("hrm.test.matrix-deprecated") and help("hrm.test.dataframe-deprecated").

Usage

hrm.test.matrix(data, alpha = 0.05)

hrm.test.dataframe(
  data,
  alpha = 0.05,
  group,
  subgroup,
  factor1,
  factor2,
  factor3,
  subject,
  response
)

Details

For hrm.test.dataframe and hrm.test.matrix use hrm_test instead.

Value

hrm.test.matrix and hrm.test.dataframe both return an object of class 'HRM', exactly as returned by hrm_test.


HRM documentation built on Sept. 11, 2026, 5:06 p.m.