hrm.0w.2s: Test for interaction of factor A and B

View source: R/f1.R

hrm.0w.2sR Documentation

Test for interaction of factor A and B

Description

Test for interaction of factor A and B

Usage

hrm.0w.2s(
  X,
  alpha,
  factor1,
  factor2,
  subject,
  data,
  H = "B",
  text = "",
  nonparametric,
  ranked,
  varQGlobal,
  np.correction,
  tmpQ1g,
  tmpQ2g
)

Arguments

X

dataframe containing the data in the long table format

alpha

alpha level used for the test

factor1

column name of the data frame X of the first factor variable

subject

column name of the data frame X identifying the subjects

data

column name of the response variable

H

string specifying the hypothesis

text

a string, which will be printed in the output

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.