| hrm.0w.3s | R Documentation |
Test for interaction of factor A and B
hrm.0w.3s(
X,
alpha,
factor1,
factor2,
factor3,
subject,
data,
H = 1,
text = "",
nonparametric,
ranked,
varQGlobal,
np.correction
)
X |
dataframe containing the data in the long table format |
alpha |
alpha level used for the test |
factor1 |
column name of the data frame X of the first factor variable |
subject |
column name of the data frame X identifying the subjects |
data |
column name of the response variable |
H |
string specifying the hypothesis |
text |
a string, which will be printed in the output |
Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.