hrm.0w.4s: Test for interaction of four subplot factors

View source: R/f4_sub4.R

hrm.0w.4sR Documentation

Test for interaction of four subplot factors

Description

Test for interaction of four subplot factors

Usage

hrm.0w.4s(
  X,
  alpha,
  factor1,
  factor2,
  factor3,
  factor4,
  subject,
  data,
  H = 1,
  text = "",
  nonparametric,
  ranked,
  varQGlobal,
  np.correction
)

Arguments

X

dataframe containing the data in the long table format

alpha

alpha level used for the test

factor1

column name of the data frame X of the first factor variable

subject

column name of the data frame X identifying the subjects

data

column name of the response variable

H

string specifying the hypothesis

text

a string, which will be printed in the output

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.