hrm.1w.0f: Test for interaction of factor A and B

View source: R/f1_sub0.R

hrm.1w.0fR Documentation

Test for interaction of factor A and B

Description

Test for interaction of factor A and B

Usage

hrm.1w.0f(
  X,
  alpha,
  group,
  subject,
  data,
  H,
  text,
  nonparametric,
  ranked,
  varQGlobal
)

Arguments

X

dataframe containing the data in the long table format

alpha

alpha level used for the test

group

column name of the data frame X specifying the groups

subject

column name of the data frame X identifying the subjects

data

column name of the response variable

H

string specifying the hypothesis

text

a string, which will be printed in the output

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.