| hrm.1w.3f | R Documentation |
Test for 1 wholeplot and 3 subplot-factors
hrm.1w.3f(
X,
alpha,
group,
factor1,
factor2,
factor3,
subject,
data,
S,
K1,
K2,
K3,
hypothesis,
nonparametric,
ranked,
varQGlobal,
np.correction
)
X |
dataframe containing the data in the long table format |
alpha |
alpha level used for the test |
group |
column name of the data frame X specifying the groups |
factor1 |
column name of the data frame X of the first factor variable |
factor2 |
column name of the data frame X of the second factor variable crossed with the first one |
factor3 |
column name of the data frame X of the third factor variable crossed with the first one |
subject |
column name of the data frame X identifying the subjects |
data |
column name of the data frame X containing the observed values |
S |
Matrix for the wholeplot factor |
K1 |
Matrix for the first subplot factor |
K2 |
Matrix for the second subplot factor |
K3 |
Matrix for the third subplot factor |
hypothesis |
String which is printed in the console as ouput to indicate which hypothesis is tested. |
Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.