| hrm.2w.2f | R Documentation |
Test for influence of factor A
hrm.2w.2f(
X,
alpha,
group,
subgroup,
factor1,
factor2,
subject,
data,
H,
text = "",
nonparametric,
ranked,
varQGlobal,
np.correction
)
X |
dataframe containing the data in the long table format |
alpha |
alpha level used for the test |
group |
column name of the data frame X specifying the groups |
subgroup |
column name of the subgroups (crossed with groups) |
subject |
column name of the data frame X identifying the subjects |
data |
column name of the data frame X containing the measurement data |
H |
string specifying the hypothesis |
text |
a string, which will be printed in the output |
Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.