hrm.A.unweighted: Test for no main treatment effect (unweighted version)

View source: R/f2_old.R

hrm.A.unweightedR Documentation

Test for no main treatment effect (unweighted version)

Description

Test for no main treatment effect (unweighted version)

Usage

hrm.A.unweighted(n, a, d, X, alpha, nonparametric = FALSE)

Arguments

n

an vector containing the sample sizes of all groups

a

number of groups

d

number of dimensions (time points)

X

list containing the data matrices of all groups

alpha

alpha level used for the test

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.