hrm.test.1.none: Test for main group effect (weighted/unweighted)

View source: R/f1_sub0.R

hrm.test.1.noneR Documentation

Test for main group effect (weighted/unweighted)

Description

Test for main group effect (weighted/unweighted)

Usage

hrm.test.1.none(X, alpha, group, subject, data, formula, nonparametric)

Arguments

X

dataframe containing the data in the long table format

alpha

alpha level used for the test

group

column name of the data frame X specifying the groups

subject

column name of the data frame X identifying the subjects

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.