hrm.test.1.one: Test for one subplot factor

View source: R/f1.R

hrm.test.1.oneR Documentation

Test for one subplot factor

Description

Test for one subplot factor

Usage

hrm.test.1.one(
  X,
  alpha,
  factor1,
  subject,
  data,
  formula,
  nonparametric,
  np.correction
)

Arguments

X

dataframe containing the data in the long table format

alpha

alpha level used for the test

factor1

column name of the data frame X of the first factor variable

subject

column name of the data frame X identifying the subjects

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value


HRM documentation built on Sept. 11, 2026, 5:06 p.m.