Learn R Programming

HRM (version 1.3.0)

hrm.B: Test for no main time effect

Description

Test for no main time effect

Usage

hrm.B(n, a, d, X, alpha, nonparametric = FALSE)

Value

Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value

Arguments

n

an vector containing the sample sizes of all groups

a

number of groups

d

number of dimensions (time points)

X

list containing the data matrices of all groups

alpha

alpha level used for the test