Test for no main time effect
hrm.B(n, a, d, X, alpha, nonparametric = FALSE)Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
an vector containing the sample sizes of all groups
number of groups
number of dimensions (time points)
list containing the data matrices of all groups
alpha level used for the test