| hrm.test.1.none | R Documentation |
Test for main group effect (weighted/unweighted)
hrm.test.1.none(X, alpha, group, subject, data, formula, nonparametric)
X |
dataframe containing the data in the long table format |
alpha |
alpha level used for the test |
group |
column name of the data frame X specifying the groups |
subject |
column name of the data frame X identifying the subjects |
Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.