| hrm.test.1.one | R Documentation |
Test for one subplot factor
hrm.test.1.one(
X,
alpha,
factor1,
subject,
data,
formula,
nonparametric,
np.correction
)
X |
dataframe containing the data in the long table format |
alpha |
alpha level used for the test |
factor1 |
column name of the data frame X of the first factor variable |
subject |
column name of the data frame X identifying the subjects |
Returns a data frame consisting of the degrees of freedom, the test value, the critical value and the p-value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.